@@ -7,7 +7,12 @@ mod operators;
 mod rewriter;
 use operators::{impl_postgres_eq, impl_postgres_hash, impl_postgres_ord};
 
-use pgx_utils::*;
+use pgx_utils::{
+    sql_entity_graph::{
+        ExtensionSql, ExtensionSqlFile, PgAggregate, PgExtern, PostgresEnum, PostgresType, Schema,
+    },
+    *,
+};
 use proc_macro::TokenStream;
 use proc_macro2::{Ident, Span};
 use quote::{quote, quote_spanned, ToTokens};
@@ -188,7 +193,7 @@ File modules (like `mod name;`) aren't able to be supported due to [`rust/#54725
 */
 #[proc_macro_attribute]
 pub fn pg_schema(_attr: TokenStream, item: TokenStream) -> TokenStream {
-    let pgx_schema = parse_macro_input!(item as sql_entity_graph::Schema);
+    let pgx_schema = parse_macro_input!(item as Schema);
     pgx_schema.to_token_stream().into()
 }
 
@@ -320,7 +325,7 @@ extension_sql!(r#"\
 #[proc_macro]
 pub fn extension_sql(input: TokenStream) -> TokenStream {
     fn wrapped(input: TokenStream) -> Result<TokenStream, syn::Error> {
-        let ext_sql: sql_entity_graph::ExtensionSql = syn::parse(input)?;
+        let ext_sql: ExtensionSql = syn::parse(input)?;
         Ok(ext_sql.to_token_stream().into())
     }
 
@@ -365,7 +370,7 @@ For all other options, and examples of them, see [`macro@extension_sql`].
 #[proc_macro]
 pub fn extension_sql_file(input: TokenStream) -> TokenStream {
     fn wrapped(input: TokenStream) -> Result<TokenStream, syn::Error> {
-        let ext_sql: sql_entity_graph::ExtensionSqlFile = syn::parse(input)?;
+        let ext_sql: ExtensionSqlFile = syn::parse(input)?;
         Ok(ext_sql.to_token_stream().into())
     }
 
@@ -526,8 +531,7 @@ fn example_return() -> pg_sys::Oid {
 pub fn pg_extern(attr: TokenStream, item: TokenStream) -> TokenStream {
     let args = parse_extern_attributes(proc_macro2::TokenStream::from(attr.clone()));
 
-    let sql_graph_entity_item =
-        sql_entity_graph::PgExtern::new(attr.clone().into(), item.clone().into()).unwrap();
+    let sql_graph_entity_item = PgExtern::new(attr.clone().into(), item.clone().into()).unwrap();
 
     let ast = parse_macro_input!(item as syn::Item);
     match ast {
@@ -539,7 +543,7 @@ pub fn pg_extern(attr: TokenStream, item: TokenStream) -> TokenStream {
 fn rewrite_item_fn(
     mut func: ItemFn,
     extern_args: HashSet<ExternArgs>,
-    sql_graph_entity_submission: &sql_entity_graph::PgExtern,
+    sql_graph_entity_submission: &PgExtern,
 ) -> proc_macro2::TokenStream {
     let is_raw = extern_args.contains(&ExternArgs::Raw);
     let no_guard = extern_args.contains(&ExternArgs::NoGuard);
@@ -568,6 +572,7 @@ fn rewrite_item_fn(
     if need_wrapper {
         quote_spanned! {func_span=>
             #[no_mangle]
+            #[doc(hidden)]
             pub extern "C" fn #finfo_name() -> &'static pg_sys::Pg_finfo_record {
                 const V1_API: pg_sys::Pg_finfo_record = pg_sys::Pg_finfo_record { api_version: 1 };
                 &V1_API
@@ -659,8 +664,7 @@ fn impl_postgres_enum(ast: DeriveInput) -> proc_macro2::TokenStream {
         }
     });
 
-    let sql_graph_entity_item =
-        sql_entity_graph::PostgresEnum::from_derive_input(sql_graph_entity_ast).unwrap();
+    let sql_graph_entity_item = PostgresEnum::from_derive_input(sql_graph_entity_ast).unwrap();
     sql_graph_entity_item.to_tokens(&mut stream);
 
     stream
@@ -738,11 +742,13 @@ fn impl_postgres_type(ast: DeriveInput) -> proc_macro2::TokenStream {
         stream.extend(quote! {
             impl #generics JsonInOutFuncs #inout_generics for #name #generics {}
 
+            #[doc(hidden)]
             #[pg_extern(immutable,parallel_safe)]
             pub fn #funcname_in #generics(input: &#lifetime pgx::cstr_core::CStr) -> #name #generics {
                 #name::input(input)
             }
 
+            #[doc(hidden)]
             #[pg_extern(immutable,parallel_safe)]
             pub fn #funcname_out #generics(input: #name #generics) -> &#lifetime pgx::cstr_core::CStr {
                 let mut buffer = StringInfo::new();
@@ -754,11 +760,13 @@ fn impl_postgres_type(ast: DeriveInput) -> proc_macro2::TokenStream {
     } else if args.contains(&PostgresTypeAttribute::InOutFuncs) {
         // otherwise if it's InOutFuncs our _in/_out functions use an owned type instance
         stream.extend(quote! {
+            #[doc(hidden)]
             #[pg_extern(immutable,parallel_safe)]
             pub fn #funcname_in #generics(input: &#lifetime pgx::cstr_core::CStr) -> #name #generics {
                 #name::input(input)
             }
 
+            #[doc(hidden)]
             #[pg_extern(immutable,parallel_safe)]
             pub fn #funcname_out #generics(input: #name #generics) -> &#lifetime pgx::cstr_core::CStr {
                 let mut buffer = StringInfo::new();
@@ -769,11 +777,13 @@ fn impl_postgres_type(ast: DeriveInput) -> proc_macro2::TokenStream {
     } else if args.contains(&PostgresTypeAttribute::PgVarlenaInOutFuncs) {
         // otherwise if it's PgVarlenaInOutFuncs our _in/_out functions use a PgVarlena
         stream.extend(quote! {
+            #[doc(hidden)]
             #[pg_extern(immutable,parallel_safe)]
             pub fn #funcname_in #generics(input: &#lifetime pgx::cstr_core::CStr) -> pgx::PgVarlena<#name #generics> {
                 #name::input(input)
             }
 
+            #[doc(hidden)]
             #[pg_extern(immutable,parallel_safe)]
             pub fn #funcname_out #generics(input: pgx::PgVarlena<#name #generics>) -> &#lifetime pgx::cstr_core::CStr {
                 let mut buffer = StringInfo::new();
@@ -783,7 +793,7 @@ fn impl_postgres_type(ast: DeriveInput) -> proc_macro2::TokenStream {
         });
     }
 
-    let sql_graph_entity_item = sql_entity_graph::PostgresType::from_derive_input(ast).unwrap();
+    let sql_graph_entity_item = PostgresType::from_derive_input(ast).unwrap();
     sql_graph_entity_item.to_tokens(&mut stream);
 
     stream
@@ -989,7 +999,7 @@ Functions inside the `impl` may use the [`#[pgx]`](macro@pgx) attribute.
 pub fn pg_aggregate(_attr: TokenStream, item: TokenStream) -> TokenStream {
     // We don't care about `_attr` as we can find it in the `ItemMod`.
     fn wrapped(item_impl: ItemImpl) -> Result<TokenStream, syn::Error> {
-        let sql_graph_entity_item = sql_entity_graph::PgAggregate::new(item_impl.into())?;
+        let sql_graph_entity_item = PgAggregate::new(item_impl.into())?;
 
         Ok(sql_graph_entity_item.to_token_stream().into())
     }
